==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/NativeUIButton.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { NativeUIDisplayDensity_$type } from "./NativeUIDisplayDensity";
import { enumGetBox, EnumUtil, markType } from "./type";
import { NativeUIButtonDisplayType_$type } from "./NativeUIButtonDisplayType";
/**
 * @hidden
 */
var NativeUIButton = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUIButton, _super);
    function NativeUIButton() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.bg = null;
        return _this;
    }
    NativeUIButton.prototype.get_e = function () {
        return 1;
    };
    Object.defineProperty(NativeUIButton.prototype, "bk", {
        get: function () {
            var a = this.ae(1);
            return a == null ? 1 : EnumUtil.getEnumValue(NativeUIDisplayDensity_$type, a);
        },
        set: function (a) {
            this.a0(1, enumGetBox(NativeUIDisplayDensity_$type, a));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bi", {
        get: function () {
            var a = this.ae(0);
            return a == null ? 0 : EnumUtil.getEnumValue(NativeUIButtonDisplayType_$type, a);
        },
        set: function (a) {
            this.a0(0, enumGetBox(NativeUIButtonDisplayType_$type, a));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bs", {
        get: function () {
            var a = this.ae(3);
            return a;
        },
        set: function (a) {
            this.a0(3, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bj", {
        get: function () {
            return this.ae(54);
        },
        set: function (a) {
            this.a0(54, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bp", {
        get: function () {
            return this.ae(4);
        },
        set: function (a) {
            this.a0(4, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bn", {
        get: function () {
            return this.ae(5);
        },
        set: function (a) {
            this.a0(5, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bm", {
        get: function () {
            return this.ae(6);
        },
        set: function (a) {
            this.a0(6, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "br", {
        get: function () {
            return this.ae(32);
        },
        set: function (a) {
            this.a0(32, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bt", {
        get: function () {
            return this.ae(24);
        },
        set: function (a) {
            this.a0(24, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bu", {
        get: function () {
            return this.ae(55);
        },
        set: function (a) {
            this.a0(55, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bq", {
        get: function () {
            return this.ae(57);
        },
        set: function (a) {
            this.a0(57, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bo", {
        get: function () {
            return this.ae(56);
        },
        set: function (a) {
            this.a0(56, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bl", {
        get: function () {
            return this.ae(58);
        },
        set: function (a) {
            this.a0(58, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bh", {
        get: function () {
            return this.bg;
        },
        set: function (a) {
            var b = this.bg;
            this.bg = a;
            if (this.bg != b) {
                if (b != null) {
                    this.ay(1, b);
                }
                if (this.bg != null) {
                    this.an(1, this.bg);
                }
            }
        },
        enumerable: false,
        configurable: true
    });
    NativeUIButton.$t = markType(NativeUIButton, 'NativeUIButton', NativeUIComponent.$);
    return NativeUIButton;
}(NativeUIComponent));
export { NativeUIButton };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/NativeUIButton.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { NativeUIDisplayDensity_$type } from "./NativeUIDisplayDensity";
import { enumGetBox, EnumUtil, markType } from "./type";
import { NativeUIButtonDisplayType_$type } from "./NativeUIButtonDisplayType";
/**
 * @hidden
 */
var NativeUIButton = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUIButton, _super);
    function NativeUIButton() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.bj = null;
        return _this;
    }
    NativeUIButton.prototype.get_e = function () {
        return 1;
    };
    Object.defineProperty(NativeUIButton.prototype, "bn", {
        get: function () {
            var a = this.ag(1);
            return a == null ? 1 : EnumUtil.getEnumValue(NativeUIDisplayDensity_$type, a);
        },
        set: function (a) {
            this.a2(1, enumGetBox(NativeUIDisplayDensity_$type, a));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bl", {
        get: function () {
            var a = this.ag(0);
            return a == null ? 0 : EnumUtil.getEnumValue(NativeUIButtonDisplayType_$type, a);
        },
        set: function (a) {
            this.a2(0, enumGetBox(NativeUIButtonDisplayType_$type, a));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bw", {
        get: function () {
            var a = this.ag(3);
            return a;
        },
        set: function (a) {
            this.a2(3, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bm", {
        get: function () {
            return this.ag(54);
        },
        set: function (a) {
            this.a2(54, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bs", {
        get: function () {
            return this.ag(4);
        },
        set: function (a) {
            this.a2(4, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bq", {
        get: function () {
            return this.ag(5);
        },
        set: function (a) {
            this.a2(5, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bp", {
        get: function () {
            return this.ag(6);
        },
        set: function (a) {
            this.a2(6, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bu", {
        get: function () {
            return this.ag(32);
        },
        set: function (a) {
            this.a2(32, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "by", {
        get: function () {
            return this.ag(24);
        },
        set: function (a) {
            this.a2(24, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bz", {
        get: function () {
            return this.ag(55);
        },
        set: function (a) {
            this.a2(55, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bt", {
        get: function () {
            return this.ag(57);
        },
        set: function (a) {
            this.a2(57, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "br", {
        get: function () {
            return this.ag(56);
        },
        set: function (a) {
            this.a2(56, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bo", {
        get: function () {
            return this.ag(58);
        },
        set: function (a) {
            this.a2(58, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bx", {
        get: function () {
            return this.ag(17);
        },
        set: function (a) {
            this.a2(17, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bi", {
        get: function () {
            return this.ag(11);
        },
        set: function (a) {
            this.a2(11, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bv", {
        get: function () {
            return this.ag(83);
        },
        set: function (a) {
            this.a2(83, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIButton.prototype, "bk", {
        get: function () {
            return this.bj;
        },
        set: function (a) {
            var b = this.bj;
            this.bj = a;
            if (this.bj != b) {
                if (b != null) {
                    this.a0(1, b);
                }
                if (this.bj != null) {
                    this.ap(1, this.bj);
                }
            }
        },
        enumerable: false,
        configurable: true
    });
    NativeUIButton.$t = markType(NativeUIButton, 'NativeUIButton', NativeUIComponent.$);
    return NativeUIButton;
}(NativeUIComponent));
export { NativeUIButton };
